<?php 

namespace Modules\Cadastros\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Doctrine\DBAL\ParameterType; 


class gql02200AvisoQualificacaoFonercedorService {
    
    protected $connection;
    
    public function __construct($entityManager, $environment)
    {
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
    }
    
    private function limpaHtmlRegex ($descricao) {
        $descricao = preg_replace('/<[<br>]>/',"\n", $descricao);
        return preg_replace('/<[^<>]+>/', '', $descricao);
    }
    
    
        /* ****************
     *    SELECT      *
     ******************/
     
    /*Verificar se o select abaixo não retorna dados:*/
    public function getCdAviso($row) 
    {
		$param = array(
		    'P_CDAVISQUALFO' => $row['P_CDAVISQUALFO']
		);


        $query = "SELECT
                     CDAVISQUALFO
                 FROM
                     AVISQUALFOR
                 WHERE
                     (CDAVISQUALFO = :P_CDAVISQUALFO)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            
            return $std->fetchAll();
        } catch (Exception $e){
            throw $e;
        }
    }
    
    
    public function getAviso($row) 
    {
		$param = array (
		    
		    'P_CDQUALPA' => $row['P_CDQUALPA'],
		    'P_CDQUALDE' => $row['P_CDQUALDE'],
		    'P_NRORG'      => $this->environment->getNrorg()
		); 

        $query = "SELECT
                     CDQUALDE, CDQUALPA, CDFILIAL, CDAVISQUALFO
                 FROM
                     AVISQUALFOR
                 WHERE
                     (CDQUALDE = :P_CDQUALDE) AND (CDQUALPA = :P_CDQUALPA) AND (NRORG = :P_NRORG)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            
            return $std->fetchAll();
        } catch (Exception $e){
            throw $e;
        }
    }
     
    /* ***************
     *    INSERT     *
     *****************/

     
     
    public function insertAvisoQualificacao($row) {
		$params =  array(
		    'P_CDAVISQUALFO' => $row['P_CDAVISQUALFO'],
		    'P_CDQUALDE' => $row['P_CDQUALDE'],
		    'P_CDQUALPA' => $row['P_CDQUALPA'],
		    'P_CDFILIAL' => $this->environment->getCdFilial()
		);
		
        $query = "INSERT INTO AVISQUALFOR
                     (CDQUALDE, CDQUALPA, DSTEXTOAVISO, CDFILIAL, CDAVISQUALFO, DSTEXTOAVISOHTML)
                 VALUES
                    (:P_CDQUALDE, :P_CDQUALPA, :P_DSTEXTOAVISO, :P_CDFILIAL, :P_CDAVISQUALFO, :P_DSTEXTOAVISOHTML)";
                    
        $P_DSTEXTOAVISO = $row['P_DSTEXTOAVISO'];
        $P_DSTEXTOAVISOHTML = $row['P_DSTEXTOAVISOHTML'];
        
        $P_DSTEXTOAVISO = substr($P_DSTEXTOAVISO, 0 , 2000);
        try {
            $std = $this->connection->prepare($query);
            $std->bindValue(':P_DSTEXTOAVISOHTML', $P_DSTEXTOAVISOHTML, ParameterType::BINARY);
            $std->bindValue(':P_DSTEXTOAVISO', $P_DSTEXTOAVISO, ParameterType::LARGE_OBJECT);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
      
    
    
    /* ****************
     *    UPDATE      *
     ******************/
    public function updateAvisoQualificacao($row) {
        
        $param = array(
            'P_CDAVISQUALFO' => $row['P_CDAVISQUALFO'],
            'P_CDFILIAL' => ($row['P_CDFILIAL'] ?  $row['P_CDFILIAL'] : $this->environment->getCdFilial())

        );
    
        $query = "UPDATE AVISQUALFOR
                        SET 
                            DSTEXTOAVISO  = :P_DSTEXTOAVISO,
                            DSTEXTOAVISOHTML = :P_DSTEXTOAVISOHTML
                        WHERE 
                            CDFILIAL   = :P_CDFILIAL AND
                            CDAVISQUALFO = :P_CDAVISQUALFO";
        
        $P_DSTEXTOAVISO = $row['P_DSTEXTOAVISO'];
        $P_DSTEXTOAVISOHTML = $row['P_DSTEXTOAVISOHTML'];
        
        $P_DSTEXTOAVISO = substr($P_DSTEXTOAVISO, 0 , 2000);
        try {
            $std = $this->connection->prepare($query);
            $std->bindValue(':P_DSTEXTOAVISOHTML', $P_DSTEXTOAVISOHTML, ParameterType::BINARY);
            $std->bindValue(':P_DSTEXTOAVISO', $P_DSTEXTOAVISO, ParameterType::LARGE_OBJECT);
            $std->execute($param);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    /* ****************
     *    DELETE      *
     ******************/
    
    public function deleteAvisoQualificacao($row) {
	    $param = array (
	        'P_CDFILIAL' => $row['P_CDFILIAL'],
	        'P_CDAVISQUALFO' => $row['P_CDAVISQUALFO']

	        );	
        $query = "DELETE FROM AVISQUALFOR
                    WHERE CDFILIAL = :P_CDFILIAL
                        AND CDAVISQUALFO = :P_CDAVISQUALFO";
        try {
                $std = $this->connection->prepare($query);
                $std->execute($param);
            } catch (Exception $e) {
                throw $e;
        }
    }

};