/* Sistemas Integrados TECNISA
   Compras e Suprimentos

Nome: CUSTO_DO_PRATO_PLA.SQL

Descrio:
Retorna o Custo do Prato.

P_CDFILIAL     - Cdigo da Filial (utilizado para pesquisar os
                 parmetros de utilizao dos fatores de correo e
                 coco alem do custo dos produtos.
P_CDFILICUSTO  - Cdigo da Filial (utilizado na funo de custo dos
                 produtos.
P_NRTIPOCUSTO  - Nmero do Tipo de Custo.
P_DTREFERENCIA - Fator de Coco.
P_CDFILAUXPRAT - Cdigo da Filial do prato.
P_CDPRATO      - Cdigo do Prato.
P_CDSERVFILI   - Cdigo do Servico.

Criao:
09/02/00 - Ftima

*/

CREATE OR REPLACE
PROCEDURE CUSTO_DO_PRATO_PLA
  (P_CDFILIAL     IN FILIAL.CDFILIAL%TYPE,
   P_CDFILICUSTO  IN FILIAL.CDFILIAL%TYPE,
   P_NRTIPOCUSTO  IN NUMBER,
   P_DTREFERENCIA IN DATE,
   P_CDFILAUXPRAT IN PRATO.CDFILAUXPRAT%TYPE,
   P_CDPRATO      IN PRATO.CDPRATO%TYPE,
   P_CDSERVFILI   IN SERVICO.CDSERVFILI%TYPE,
   P_CUSTO_PRATO  OUT NUMBER) IS

   V_IDUTILFATCOR    PARAMPLANEJA.IDUTILFATCOR%TYPE;
   V_IDUTILFATCOC    PARAMPLANEJA.IDUTILFATCOC%TYPE;
   V_IDTIPCALCFAT    PARAMPLANEJA.IDTIPCALCFAT%TYPE;

   V_CDPRODUTO   PRODUTO.CDPRODUTO%TYPE;
   V_QTPRODUTO   NUMBER;
   V_CUSTO_PRATO NUMBER;
   V_UNIDADE_ESTOQUE NUMBER;
   V_CUSTO_DO_PRODUTO NUMBER;
   V_QTPRODRECSER NUMBER;
   V_SGUNIDADE    NUMBER;
   V_VRPEFATCOCSE NUMBER;
   V_VRPEFATCORSE NUMBER;

   CURSOR C_CUSTO_DO_PRATO IS
    (SELECT
        CDPRODUTO,
        QTBRUTASE AS QTPRODUTO
     FROM
        RECESERV
     WHERE
        (CDFILAUXPRAT = P_CDFILAUXPRAT) AND
        (CDPRATO      = P_CDPRATO)      AND
        (CDFILIAL     = P_CDFILIAL)     AND
        (CDSERVFILI   = P_CDSERVFILI)

     UNION

     SELECT
        CDPRODUTO,
        QTBRUTALO AS QTPRODUTO
     FROM
        RECEFILI
     WHERE
        (CDFILAUXPRAT = P_CDFILAUXPRAT) AND
        (CDPRATO      = P_CDPRATO)      AND
        (CDFILIAL     = P_CDFILIAL)     AND
         NOT EXISTS (SELECT
                        CDPRATO
                     FROM
                        RECESERV
                     WHERE
                        (CDFILAUXPRAT = P_CDFILAUXPRAT) AND
                        (CDPRATO      = P_CDPRATO)                        AND
                        (CDFILIAL     = P_CDFILIAL)                       AND
                        (CDSERVFILI   = P_CDSERVFILI)
                     )
     UNION

     SELECT
        CDPRODUTO,
        QTBRUTAPR  AS QTPRODUTO
     FROM
        RECEPADR
     WHERE
        (CDFILAUXPRAT = P_CDFILAUXPRAT) AND
        (CDPRATO      = P_CDPRATO)      AND
         NOT EXISTS (SELECT
                        CDPRATO
                     FROM
                        RECEFILI
                     WHERE
                        (CDFILAUXPRAT = P_CDFILAUXPRAT) AND
                        (CDPRATO      = P_CDPRATO)      AND
                        (CDFILIAL     = P_CDFILIAL)
                     ) AND
         NOT EXISTS (SELECT
                        CDPRATO
                     FROM
                        RECESERV
                     WHERE
                        (CDFILAUXPRAT = P_CDFILAUXPRAT) AND
                        (CDPRATO      = P_CDPRATO)      AND
                        (CDFILIAL     = P_CDFILIAL)     AND
                        (CDSERVFILI   = P_CDSERVFILI)
                     )
     );

BEGIN

   SELECT
      MAX(IDUTILFATCOR),
      MAX(IDUTILFATCOC),
      MAX(IDTIPCALCFAT)
   INTO
      V_IDUTILFATCOR,
      V_IDUTILFATCOC,
      V_IDTIPCALCFAT
   FROM
      PARAMPLANEJA
   WHERE
      CDFILIAL = P_CDFILIAL;

   IF V_IDUTILFATCOR IS NULL THEN
      V_IDUTILFATCOC := 'S';
      V_IDUTILFATCOR := 'S';
      V_IDTIPCALCFAT := 'T';
   END IF;

   V_CUSTO_PRATO := 0;

   OPEN C_CUSTO_DO_PRATO;
   LOOP
      FETCH C_CUSTO_DO_PRATO
      INTO V_CDPRODUTO,
           V_QTPRODUTO;
      EXIT WHEN C_CUSTO_DO_PRATO%NOTFOUND;

      CUSTO_DO_PRODUTO_PLA(P_CDFILICUSTO, V_CDPRODUTO, P_NRTIPOCUSTO, P_DTREFERENCIA,
                           V_CUSTO_DO_PRODUTO);

      V_CUSTO_PRATO := V_CUSTO_PRATO + (ROUND(V_QTPRODUTO, 5) * ROUND(V_CUSTO_DO_PRODUTO, 5));

   END LOOP;

   CLOSE C_CUSTO_DO_PRATO;

   P_CUSTO_PRATO := ROUND(V_CUSTO_PRATO,5);

END;
/


